<?php

namespace Database\Seeders;

use App\Models\Package;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;

class PackageSeeder extends Seeder
{
	/**
	 * Run the database seeds.
	 *
	 * @return void
	 */
	public function run()
	{
		// Packages' "active" column value
		$appUrl = config('app.url'); // env('APP_URL');
		$isDemoDomain = (isDemoDomain($appUrl) || isDevEnv($appUrl));
		$activeValue = $isDemoDomain ? '1' : '0';
		
		$entries = [
			// promotion
			[
				'type'                  => 'promotion',
				'name'                  => [
					'en' => 'Regular List',
					'fr' => 'Gratuit',
					'es' => 'Lista regular',
					'ar' => 'قائمة منتظمة',
					'pt' => 'Lista Regular',
					'ru' => 'Обычный список',
					'tr' => 'Normal Liste',
					'th' => 'รายการปกติ',
					'ka' => 'რეგულარული სია',
					'zh' => '常规清单',
					'ja' => 'レギュラーリスト',
					'it' => 'Elenco regolare',
					'ro' => 'Lista regulată',
					'de' => 'Regelmäßige Liste',
					'hi' => 'नियमित सूची',
					'bn' => 'নিয়মিত তালিকা',
					'he' => 'רשימה רגילה',
				],
				'short_name'            => [
					'en' => 'Free',
					'fr' => 'Standard',
					'es' => 'Estándar',
					'ar' => 'اساسي',
					'pt' => 'Padrão',
					'ru' => 'Стандарт',
					'tr' => 'Standart',
					'th' => 'มาตรฐาน',
					'ka' => 'სტანდარტული',
					'zh' => '标准',
					'ja' => '標準',
					'it' => 'Standard',
					'ro' => 'Standard',
					'de' => 'Standard',
					'hi' => 'नि: शुल्क',
					'bn' => 'মুক্ত',
					'he' => 'חינם',
				],
				'ribbon'                => 'red',
				'has_badge'             => '1',
				'price'                 => '0.00',
				'currency_code'         => 'USD',
				'promotion_time'        => null,
				'expiration_time'       => null,
				'pictures_limit'        => null,
				'description'           => null,
				'facebook_ads_duration' => '0',
				'google_ads_duration'   => '0',
				'twitter_ads_duration'  => '0',
				'linkedin_ads_duration' => '0',
				'recommended'           => '0',
				'parent_id'             => null,
				'lft'                   => '2',
				'rgt'                   => '3',
				'depth'                 => '0',
				'active'                => $activeValue,
			],
			[
				'type'                  => 'promotion',
				'name'                  => [
					'en' => 'Premium Listing',
					'fr' => 'Annonce Premium',
					'es' => 'Anuncio premium',
					'ar' => 'إعلان مميز',
					'pt' => 'Anúncio Premium',
					'ru' => 'Премиум-объявление',
					'tr' => 'Premium Reklam',
					'th' => 'โฆษณาพรีเมียม',
					'ka' => 'პრემიუმ რეკლამა',
					'zh' => '优质广告',
					'ja' => 'プレミアム広告',
					'it' => 'Annuncio premium',
					'ro' => 'Anunț premium',
					'de' => 'Premium-Anzeige',
					'hi' => 'प्रीमियम विज्ञापन',
					'bn' => 'প্রিমিয়াম বিজ্ঞাপন',
					'he' => 'מודעת פרימיום',
				],
				'short_name'            => [
					'en' => 'Premium',
					'fr' => 'Premium',
					'es' => 'Prima',
					'ar' => 'الممتازة',
					'pt' => 'Prêmio',
					'ru' => 'Премиум',
					'tr' => 'Ödül',
					'th' => 'พรีเมียม',
					'ka' => 'პრემია',
					'zh' => '保费',
					'ja' => 'プレミアム',
					'it' => 'Premium',
					'ro' => 'Premium',
					'de' => 'Prämie',
					'hi' => 'अधिमूल्य',
					'bn' => 'প্রিমিয়াম',
					'he' => 'פּרֶמיָה',
				],
				'ribbon'                => 'orange',
				'has_badge'             => '1',
				'price'                 => '7.50',
				'currency_code'         => 'USD',
				'promotion_time'        => '7',
				'expiration_time'       => '60',
				'pictures_limit'        => '10',
				'description'           => [
					'en' => "Featured on the homepage\nFeatured in the category",
					'fr' => "En vedette à l'accueil\nEn vedette dans la catégorie",
					'es' => "Destacado en la página de inicio\nDestacado en la categoría",
					'ar' => "ظهرت على الصفحة الرئيسية\nظهرت في الفئة",
					'pt' => "Apresentado na página inicial\nApresentado na categoria",
					'ru' => "Показано на главной странице\nВ категории",
					'tr' => "Ana Sayfada Öne Çıkanlar\nKategoride Öne Çıkanlar",
					'th' => "นำเสนอในหน้าแรก\nนำเสนอในหมวดหมู่",
					'ka' => "მთავარ გვერდზე\nმთავარი კატეგორიაში",
					'zh' => "精选在首页上\n列入类别",
					'ja' => "ホームページに掲載\nカテゴリーで紹介",
					'it' => "In primo piano sulla home page\nIn primo piano nella categoria",
					'ro' => "Prezentat pe pagina de pornire\nPrezentat în categorie",
					'de' => "Auf der Homepage vorgestellt\nGekennzeichnet in der Kategorie",
					'hi' => "मुखपृष्ठ पर विशेष रुप से प्रदर्शित\nश्रेणी में विशेष रुप से प्रदर्शित",
					'bn' => "হোমপেজে বৈশিষ্ট্যযুক্ত\nবিষয়শ্রেণীতে বৈশিষ্ট্যযুক্ত",
					'he' => "מוצג בדף הבית\nמוצג בקטגוריה",
				],
				'facebook_ads_duration' => '0',
				'google_ads_duration'   => '0',
				'twitter_ads_duration'  => '0',
				'linkedin_ads_duration' => '0',
				'recommended'           => '1',
				'parent_id'             => null,
				'lft'                   => '4',
				'rgt'                   => '5',
				'depth'                 => '0',
				'active'                => $activeValue,
			],
			[
				'type'                  => 'promotion',
				'name'                  => [
					'en' => 'Premium Listing (+)',
					'fr' => 'Annonce Premium (+)',
					'es' => 'Anuncio premium (+)',
					'ar' => 'إعلان مميز (+)',
					'pt' => 'Anúncio Premium (+)',
					'ru' => 'Премиум-объявление (+)',
					'tr' => 'Premium Reklam (+)',
					'th' => 'โฆษณาพรีเมียม (+)',
					'ka' => 'პრემიუმ რეკლამა (+)',
					'zh' => '优质广告 (+)',
					'ja' => 'プレミアム広告 (+)',
					'it' => 'Annuncio premium (+)',
					'ro' => 'Anunț premium (+)',
					'de' => 'Premium-Anzeige (+)',
					'hi' => 'प्रीमियम विज्ञापन (+)',
					'bn' => 'প্রিমিয়াম বিজ্ঞাপন (+)',
					'he' => 'מודעת פרימיום (+)',
				],
				'short_name'            => [
					'en' => 'Premium+',
					'fr' => 'Premium+',
					'es' => 'Prima+',
					'ar' => 'الممتازة+',
					'pt' => 'Prêmio+',
					'ru' => 'Премиум+',
					'tr' => 'Ödül+',
					'th' => 'พรีเมียม+',
					'ka' => 'პრემია+',
					'zh' => '保费+',
					'ja' => 'プレミアム+',
					'it' => 'Premium+',
					'ro' => 'Premium+',
					'de' => 'Prämie+',
					'hi' => 'प्रीमियम+',
					'bn' => 'প্রিমিয়াম+',
					'he' => 'פרימיום+',
				],
				'ribbon'                => 'green',
				'has_badge'             => '1',
				'price'                 => '9.00',
				'currency_code'         => 'USD',
				'promotion_time'        => '30',
				'expiration_time'       => '120',
				'pictures_limit'        => '15',
				'description'           => [
					'en' => "Featured on the homepage\nFeatured in the category",
					'fr' => "En vedette à l\'accueil\nEn vedette dans la catégorie",
					'es' => "Destacado en la página de inicio\nDestacado en la categoría",
					'ar' => "ظهرت على الصفحة الرئيسية\nظهرت في الفئة",
					'pt' => "Apresentado na página inicial\nApresentado na categoria",
					'ru' => "Показано на главной странице\nВ категории",
					'tr' => "Ana Sayfada Öne Çıkanlar\nKategoride Öne Çıkanlar",
					'th' => "นำเสนอในหน้าแรก\nนำเสนอในหมวดหมู่",
					'ka' => "მთავარ გვერდზე\nმთავარი კატეგორიაში",
					'zh' => "精选在首页上\n列入类别",
					'ja' => "ホームページに掲載\nカテゴリーで紹介",
					'it' => "In primo piano sulla home page\nIn primo piano nella categoria",
					'ro' => "Prezentat pe pagina de pornire\nPrezentat în categorie",
					'de' => "Auf der Homepage vorgestellt\nGekennzeichnet in der Kategorie",
					'hi' => "मुखपृष्ठ पर विशेष रुप से प्रदर्शित\nश्रेणी में विशेष रुप से प्रदर्शित",
					'bn' => "হোমপেজে বৈশিষ্ট্যযুক্ত\nবিষয়শ্রেণীতে বৈশিষ্ট্যযুক্ত",
					'he' => "מוצג בדף הבית\nמוצג בקטגוריה",
				],
				'facebook_ads_duration' => '0',
				'google_ads_duration'   => '0',
				'twitter_ads_duration'  => '0',
				'linkedin_ads_duration' => '0',
				'recommended'           => '0',
				'parent_id'             => null,
				'lft'                   => '6',
				'rgt'                   => '7',
				'depth'                 => '0',
				'active'                => $activeValue,
			],
			
			// subscription
			[
				'type'            => 'subscription',
				'name'            => [
					'en' => 'Basic',
					'fr' => 'Basique',
					'es' => 'Básico',
					'ar' => 'أساسي',
					'pt' => 'Básico',
					'ru' => 'Базовый',
					'tr' => 'Temel',
					'th' => 'ขั้นพื้นฐาน',
					'ka' => 'ძირითადი',
					'zh' => '基本的',
					'ja' => '基本',
					'it' => 'Di base',
					'ro' => 'De bază',
					'de' => 'Basic',
					'hi' => 'बुनियादी',
					'bn' => 'মৌলিক',
					'he' => 'בסיסי',
				],
				'short_name'      => [
					'en' => 'Basic',
					'fr' => 'Basique',
					'es' => 'Básico',
					'ar' => 'أساسي',
					'pt' => 'Básico',
					'ru' => 'Базовый',
					'tr' => 'Temel',
					'th' => 'ขั้นพื้นฐาน',
					'ka' => 'ძირითადი',
					'zh' => '基本的',
					'ja' => '基本',
					'it' => 'Di base',
					'ro' => 'De bază',
					'de' => 'Basic',
					'hi' => 'बुनियादी',
					'bn' => 'মৌলিক',
					'he' => 'בסיסי',
				],
				'price'           => '0.00',
				'currency_code'   => 'USD',
				'interval'        => 'month', // week, month, year or null
				'listings_limit'  => null,
				'expiration_time' => null,
				'pictures_limit'  => null,
				'description'     => null,
				'recommended'     => '0',
				'parent_id'       => null,
				'lft'             => '8',
				'rgt'             => '9',
				'depth'           => '0',
				'active'          => $activeValue,
			],
			[
				'type'            => 'subscription',
				'name'            => [
					'en' => 'Premium',
					'fr' => 'Premium',
					'es' => 'Prima',
					'ar' => 'الممتازة',
					'pt' => 'Prêmio',
					'ru' => 'Премиум',
					'tr' => 'Ödül',
					'th' => 'พรีเมียม',
					'ka' => 'პრემია',
					'zh' => '保费',
					'ja' => 'プレミアム',
					'it' => 'Premium',
					'ro' => 'Premium',
					'de' => 'Prämie',
					'hi' => 'अधिमूल्य',
					'bn' => 'প্রিমিয়াম',
					'he' => 'פּרֶמיָה',
				],
				'short_name'      => [
					'en' => 'Premium',
					'fr' => 'Premium',
					'es' => 'Prima',
					'ar' => 'الممتازة',
					'pt' => 'Prêmio',
					'ru' => 'Премиум',
					'tr' => 'Ödül',
					'th' => 'พรีเมียม',
					'ka' => 'პრემია',
					'zh' => '保费',
					'ja' => 'プレミアム',
					'it' => 'Premium',
					'ro' => 'Premium',
					'de' => 'Prämie',
					'hi' => 'अधिमूल्य',
					'bn' => 'প্রিমিয়াম',
					'he' => 'פּרֶמיָה',
				],
				'price'           => '9.00',
				'currency_code'   => 'USD',
				'interval'        => 'month', // week, month, year or null
				'listings_limit'  => '100',
				'expiration_time' => '90',
				'pictures_limit'  => '10',
				'description'     => null,
				'recommended'     => '1',
				'parent_id'       => null,
				'lft'             => '10',
				'rgt'             => '11',
				'depth'           => '0',
				'active'          => $activeValue,
			],
		];
		
		$tableName = (new Package())->getTable();
		foreach ($entries as $entry) {
			$entry = arrayTranslationsToJson($entry);
			$entryId = DB::table($tableName)->insertGetId($entry);
		}
	}
}
